package com.xkrs.controller;

import com.xkrs.dao.SpecDao;
import com.xkrs.encapsulation.PromptMessageEnum;
import com.xkrs.model.entity.SpecEntity;
import com.xkrs.model.qo.SpecQo;
import com.xkrs.service.SpecService;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Locale;
import java.util.Optional;

import static com.xkrs.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * @Author: XinYi Song
 * @Date: 2022/1/20 16:01
 */
@RestController
public class SpecController {

    @Resource
    private SpecService specService;

    @Resource
    private SpecDao specDao;

    /**
     * 添加规格数据
     *
     * @param specQo
     */
    @PostMapping("/insertSpec")
    public String insertSpec(@RequestBody SpecQo specQo) {
        return specService.insertSpec(specQo);
    }

    /**
     * 查询规格信息
     */
    @GetMapping("/selectSpec")
    public String selectSpec(@RequestParam("partNo") String partNo, @RequestParam("inspectionItemCode") String inspectionItemCode) {
        Locale locale = LocaleContextHolder.getLocale();
        Optional<SpecEntity> byPartNoAndInspectionItemCode = specDao.findByPartNoAndInspectionItemCode(partNo, inspectionItemCode);
        if (byPartNoAndInspectionItemCode.isEmpty()) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "暂时没有该零件的规格信息！", locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, byPartNoAndInspectionItemCode.get(), locale);
    }
}
