package com.xkrs.dao;

import com.xkrs.model.entity.DataSource;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Optional;

/**
 * @Author: XinYi Song
 * @Date: 2022/1/19 16:41
 */
@Component
public interface DataSourceDao extends JpaRepository<DataSource, Long>, JpaSpecificationExecutor<DataSource> {

    /**
     * 查询测量数据信息
     *
     * @param lotNo      批次号
     * @param machineNo  机器号
     * @param materialNo 物料号
     * @param modelNo    模具号
     * @param partNo     零件号
     * @return
     */
    @Query(value = "SELECT * FROM qc_inspection_data_source WHERE lot_no = ? AND machine_no = ? AND material_no = ? AND model_no = ? AND part_no = ? ", nativeQuery = true)
    List<DataSource> selectDataSource(String lotNo, String machineNo, String materialNo, String modelNo, String partNo);

    /**
     * 查询全部的测量信息
     *
     * @return
     */
    @Query(value = "SELECT * FROM qc_inspection_data_source", nativeQuery = true)
    List<DataSource> selectAllSource();
}
